@@ -60,7 +60,6 @@ class RawClient(RawWrapper):
         self.check_api_config()
 
     def _process_entity_json(self, json):
-        print(json)
         group = json['entity_id'].split('.')[0]
         entity = self._entity_types.get(group, Entity)
         return entity(json)
@@ -138,8 +137,6 @@ class RawClient(RawWrapper):
 
     def set_entity(self, entity_id:str, state: str, **attributes):
         data = {'state': state}
-        if attributes:
-            data.update({'attributes': attributes})
         res = self.request(
             f'states/{entity_id}',
             method='POST',
